@@ -1,19 +1,39 @@
 use std::any::type_name;
+use std::borrow::BorrowMut;
 use std::fmt::Display;
 use std::fmt::Debug;
 use std::fmt::format;
+use std::iter::FromIterator;
 use std::ops::Range;
+use std::str::Chars;
 
 use crate::*;
-
-/// A `Iterator<Item = char>` struct for parsing. 
+  
+/// Struct to facilitate parsing.
 #[derive(Clone, Debug)]
 pub struct Parser {
 
-	pub(crate) string: String,
-	pub(crate) index: usize,
-	pub(crate) history: Vec<String>
+	input: String,
+	history: Vec<String>,
+	index: usize,
+	pub should_skip_whitespace: bool
 
+}
+
+impl<T : Display> From<T> for Parser {
+
+	fn from(other: T) -> Self {
+		
+		Parser {
+
+			input: other.to_string(),
+			history: Vec::default(),
+			index: 0,
+			should_skip_whitespace: false 
+
+		}
+
+	}
 
 }
 
@@ -23,7 +43,7 @@ impl Iterator for Parser {
 
 	fn next(&mut self) -> Option<Self::Item> {
 		
-		let result = self.string.chars().nth(self.index);
+		let result = self.input.chars().nth(self.index);
 		
 		self.index += 1;
 
@@ -34,21 +54,6 @@ impl Iterator for Parser {
 }
 
 
-impl<T : Display> From<T> for Parser {
-
-	fn from(other: T) -> Self {
-		
-		Parser {
-
-			string: other.to_string(),
-			index: 0,
-			history: Vec::default()
-
-		}
-
-	}
-
-} 
 
 impl Parser {
 
@@ -57,8 +62,33 @@ impl Parser {
 
 		self.history.push(type_name::<T>().to_string());
 		
-		T::expect_from(self)
+		if self.should_skip_whitespace { Maybe::<Spaces>::expect_from(self); }
+		
+		let result = T::expect_from(self);
+		
+		if self.should_skip_whitespace && result.is_ok() { Maybe::<Spaces>::expect_from(self); }
+
+		result
+
+	}
 	
+	pub fn input(&self) -> String {
+
+		self.input.to_string()
+
+	}
+
+	pub fn index(&self) -> usize {
+
+	
+		self.index
+
+	}
+
+	pub fn history(&self) -> Vec<String> {
+
+		self.history.clone()
+
 	}
 
 }
