@@ -6,13 +6,15 @@ use crate::Expect;
 use crate::Parser;
 use crate::Result;
 
-/// Parsed from a `Parser` pointing to one or more whitespace characters.
+/// Parses a `String` of one or more whitespace characters.
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
-pub struct Spaces(pub(crate) String);
+pub struct Spaces;
 
 impl Expect for Spaces {
 
-	fn expect_from(parser: &mut Parser) -> Result<Self>
+	type Target = String;
+
+	fn expect_from(parser: &mut Parser) -> Result<Self::Target>
 	where Self : Sized + Debug {
 
 		let cloned_iterator = parser.clone();
@@ -25,20 +27,10 @@ impl Expect for Spaces {
 
 			parser.advance_by(string.len());
 
-			Ok(Spaces(string))
+			Ok(string)
 
 		}
 	
 	}
 
 }
-
-impl Display for Spaces {
-
-	fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-		
-		write!(f, "{}", self.0)
-
-	}
-
-}
